==> ooo_dev_tools-0.22.0.tar.gz: ooo_dev_tools-0.22.0/ooodev/format/writer/modify/para/font/__init__.py <==
import uno
from ooo.dyn.awt.font_strikeout import FontStrikeoutEnum as FontStrikeoutEnum
from ooo.dyn.awt.font_underline import FontUnderlineEnum as FontUnderlineEnum
from ooo.dyn.style.case_map import CaseMapEnum as CaseMapEnum
from ooo.dyn.awt.font_relief import FontReliefEnum as FontReliefEnum

from ooodev.format.inner.direct.write.char.font.font_effects import FontLine as FontLine
from ooodev.format.inner.direct.write.char.font.font_only import FontLang as FontLang
from ooodev.format.inner.direct.write.char.font.font_position import CharSpacingKind as CharSpacingKind
from ooodev.format.inner.direct.write.char.font.font_position import FontScriptKind as FontScriptKind
from ooodev.format.inner.modify.write.para.font.font_effects import FontEffects as FontEffects
from ooodev.format.inner.modify.write.para.font.font_effects import InnerFontEffects as InnerFontEffects
from ooodev.format.inner.modify.write.para.font.font_only import FontOnly as FontOnly
from ooodev.format.inner.modify.write.para.font.font_only import InnerFontOnly as InnerFontOnly
from ooodev.format.inner.modify.write.para.font.font_position import FontPosition as FontPosition
from ooodev.format.inner.modify.write.para.font.font_position import InnerFontPosition as InnerFontPosition
from ooodev.format.writer.style.para import StyleParaKind as StyleParaKind
from ooodev.units import Angle as Angle
from ooodev.utils.data_type.intensity import Intensity as Intensity


__all__ = ["FontEffects", "FontOnly", "FontPosition"]

==> ooo_dev_tools-0.36.3.tar.gz: ooo_dev_tools-0.36.3/ooodev/format/writer/modify/para/font/__init__.py <==
import uno
from ooo.dyn.awt.font_strikeout import FontStrikeoutEnum as FontStrikeoutEnum
from ooo.dyn.awt.font_underline import FontUnderlineEnum as FontUnderlineEnum
from ooo.dyn.style.case_map import CaseMapEnum as CaseMapEnum
from ooo.dyn.awt.font_relief import FontReliefEnum as FontReliefEnum

from ooodev.format.inner.direct.write.char.font.font_effects import FontLine as FontLine
from ooodev.format.inner.direct.write.char.font.font_only import FontLang as FontLang
from ooodev.format.inner.direct.write.char.font.font_position import CharSpacingKind as CharSpacingKind
from ooodev.format.inner.direct.write.char.font.font_position import FontScriptKind as FontScriptKind
from ooodev.format.inner.modify.write.para.font.font_effects import FontEffects as FontEffects
from ooodev.format.inner.direct.write.char.font.font_effects import FontEffects as InnerFontEffects
from ooodev.format.inner.modify.write.para.font.font_only import FontOnly as FontOnly
from ooodev.format.inner.direct.write.char.font.font_only import FontOnly as InnerFontOnly
from ooodev.format.inner.modify.write.para.font.font_position import FontPosition as FontPosition
from ooodev.format.inner.direct.write.char.font.font_position import FontPosition as InnerFontPosition
from ooodev.format.writer.style.para.kind.style_para_kind import StyleParaKind as StyleParaKind
from ooodev.units.angle import Angle as Angle
from ooodev.utils.data_type.intensity import Intensity as Intensity


__all__ = ["FontEffects", "FontOnly", "FontPosition"]
